#!/usr/bin/python3

# This is a list of unit tests that currently fail for various reasons.
# This list is skipped in unit-tests-stable.py
# This list is run in unit-tests-flaky.py

flaky_test_dirs = [
    'ansible_collections/cisco/dnac',                        # TypeError: TestDnacDiscoveryIntent.__init__() takes 1 positional argument but 2 were given
    'ansible_collections/community/dns',                    # [1]
    'ansible_collections/community/general',                # import broken
    'ansible_collections/community/hrobot',                 # [1]
    'ansible_collections/dellemc/openmanage',               # E   ModuleNotFoundError: No module named 'ansible_collections.dellemc.openmanage.tests.unit.plugins.modules.utils'
    'ansible_collections/dellemc/os10',                     # [0]
    'ansible_collections/dellemc/os6',                      # [0]
    'ansible_collections/dellemc/os9',                      # E   ModuleNotFoundError: No module named 'ansible.compat.tests'
    'ansible_collections/infoblox/nios_modules',            # E   ImportError: cannot import name 'unittest' from 'ansible_collections.infoblox.nios_modules.tests.unit.compat'
    'ansible_collections/junipernetworks/junos',            # test broken
    'ansible_collections/netapp_eseries/santricity',        # [0]
    'ansible_collections/netapp/ontap',                     # missing netapp_lib
    'ansible_collections/ngine_io/cloudstack',              # [0]
    'ansible_collections/purestorage/fusion',               # E   ModuleNotFoundError: No module named 'fusion'
]

# [0] test/units/compat/mock.py from ansible-core source is not installed
#     in the binary package. Need to check why.
# [1] E   ModuleNotFoundError: No module named 'ansible_collections.community.internal_test_tools'
# [2] E   ansible_collections.sensu.sensu_go.tests.unit.plugins.modules.common.utils.AnsibleFailJson: {'msg': "argument 'pool_size' is of type <class 'NoneType'> and we were unable to convert to int: <class 'NoneType'> cannot be converted to an int", 'failed': True}
